==> jc-1.4.0.tar.gz: javax/imageio/ImageIO__24ReaderMIMETypeFilter.h <==
// final class javax.imageio.ImageIO$ReaderMIMETypeFilter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e5ded13b5c2a0699 javax_imageio_ImageIO__24ReaderMIMETypeFilter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_ImageIO__24ReaderMIMETypeFilter_H_
#define _JC_javax_imageio_ImageIO__24ReaderMIMETypeFilter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_refs	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_refs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_nonrefs	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$refs	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$refs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$nonrefs	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$object	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$object;

typedef const struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vmethods	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vmethods;
typedef const struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtable	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtable;
typedef const struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtype	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtype;

// Constructors
extern void _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$method$filter$c61550eb8d89c82b(_jc_env *, struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$method_info$filter$c61550eb8d89c82b;

// Virtual methods structure
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vmethods {
	jboolean	(*filter$c61550eb8d89c82b)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vmethods	javax_imageio_ImageIO__24ReaderMIMETypeFilter;
};

// Vtype
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtype {
	_jc_type			type;
	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_refs {
	struct _jc_java_lang_String$object	*MIMEType;
};

// Reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$refs {
    _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_refs	javax_imageio_ImageIO__24ReaderMIMETypeFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_nonrefs	javax_imageio_ImageIO__24ReaderMIMETypeFilter;
};

// Object instance structure
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$object {
	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtype	*vtype;
	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtype _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_ImageIO__24ReaderMIMETypeFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$class_object;

#endif	/* _JC_javax_imageio_ImageIO__24ReaderMIMETypeFilter_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/ImageIO__24ReaderMIMETypeFilter.h <==
// final class javax.imageio.ImageIO$ReaderMIMETypeFilter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e5ded13b5c2a0699 javax_imageio_ImageIO__24ReaderMIMETypeFilter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_ImageIO__24ReaderMIMETypeFilter_H_
#define _JC_javax_imageio_ImageIO__24ReaderMIMETypeFilter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_refs	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_refs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_nonrefs	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$refs	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$refs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$nonrefs	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$object	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$object;

typedef const struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vmethods	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vmethods;
typedef const struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtable	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtable;
typedef const struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtype	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtype;

// Constructors
extern void _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$method$filter$c61550eb8d89c82b(_jc_env *, struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$method_info$filter$c61550eb8d89c82b;

// Virtual methods structure
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vmethods {
	jboolean	(*filter$c61550eb8d89c82b)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vmethods	javax_imageio_ImageIO__24ReaderMIMETypeFilter;
};

// Vtype
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtype {
	_jc_type			type;
	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_refs {
	struct _jc_java_lang_String$object	*MIMEType;
};

// Reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$refs {
    _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_refs	javax_imageio_ImageIO__24ReaderMIMETypeFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$sub_nonrefs	javax_imageio_ImageIO__24ReaderMIMETypeFilter;
};

// Object instance structure
struct _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$object {
	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtype	*vtype;
	_jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$vtype _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_ImageIO__24ReaderMIMETypeFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_ImageIO__24ReaderMIMETypeFilter$class_object;

#endif	/* _JC_javax_imageio_ImageIO__24ReaderMIMETypeFilter_H_ */
